@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 from PyQt4 import QtCore, QtGui
-import os
 import time
 import zipfile
 
@@ -192,7 +191,7 @@ class Ui_MainWindow(object):
 
     def savePage(self):
         s=str(self.page)
-        os.chmod("/opt/quran/quran_track.ptr",0666)
+
 	f = open('/opt/quran/quran_track.ptr', "w")
         f.write(s)
         f.close()
